/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 23-Jan-2006
 * Author: Dibyendu Majumdar
 */
package entity.tpcc;

import java.io.Serializable;
import java.math.BigDecimal;
import java.sql.Timestamp;

import javax.persistence.AttributeOverride;
import javax.persistence.AttributeOverrides;
import javax.persistence.Column;
import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Version;

@Entity
@Table(name = "CUSTOMER", schema = "TPCC")
public class Customer implements Serializable {

	Long customerId;

	String firstName;

	String middleName;

	String lastName;

	Address address;

	String phone;

	Timestamp since;

	String credit = "GC";

	BigDecimal creditLimit;

	BigDecimal discount;

	BigDecimal balance;

	BigDecimal ytdPayment;

	Long paymentCount;

	Long deliveryCount;

	String data;

	District district;

	Long version;

	//    Set<Order> orders;

	@Embedded
	@AttributeOverrides( { @AttributeOverride(name = "street1", column = @Column(name = "C_STREET_1")), @AttributeOverride(name = "street2", column = @Column(name = "C_STREET_2")), @AttributeOverride(name = "city", column = @Column(name = "C_CITY")), @AttributeOverride(name = "state", column = @Column(name = "C_STATE")), @AttributeOverride(name = "zip", column = @Column(name = "C_ZIP")) })
	public Address getAddress() {
		return address;
	}

	@Column(name = "C_BALANCE", precision = 12, scale = 2)
	public BigDecimal getBalance() {
		return balance;
	}

	@Column(name = "C_CREDIT", length = 2)
	public String getCredit() {
		return credit;
	}

	@Column(name = "C_CREDIT_LIM", precision = 12, scale = 2)
	public BigDecimal getCreditLimit() {
		return creditLimit;
	}

	@Id
	@Column(name = "C_ID", nullable = false)
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	public Long getCustomerId() {
		return customerId;
	}

	@Column(name = "C_DATA")
	public String getData() {
		return data;
	}

	@Column(name = "C_DELIVERY_CNT", length = 4, precision = 4)
	public Long getDeliveryCount() {
		return deliveryCount;
	}

	@Column(name = "C_DISCOUNT", precision = 4)
	public BigDecimal getDiscount() {
		return discount;
	}

	@Column(name = "C_PAYMENT_CNT", length = 4, precision = 4)
	public Long getPaymentCount() {
		return paymentCount;
	}

	@Column(name = "C_PHONE", length = 16)
	public String getPhone() {
		return phone;
	}

	@Column(name = "C_SINCE")
	//    @Temporal(TemporalType.TIMESTAMP)
	public Timestamp getSince() {
		return since;
	}

	@Column(name = "C_YTD_PAYMENT")
	public BigDecimal getYtdPayment() {
		return ytdPayment;
	}

	@ManyToOne(targetEntity = entity.tpcc.District.class)
	@JoinColumn(name = "C_D_ID", nullable = false, referencedColumnName = "D_ID")
	public District getDistrict() {
		return district;
	}

	@Version
	@Column(name = "C_VERSION")
	public Long getVersion() {
		return version;
	}

	@Column(name = "C_FIRST", length = 16)
	public String getFirstName() {
		return firstName;
	}

	@Column(name = "C_LAST", length = 16)
	public String getLastName() {
		return lastName;
	}

	@Column(name = "C_MIDDLE", length = 2)
	public String getMiddleName() {
		return middleName;
	}

	//    @OneToMany(mappedBy="customer")
	//    public Set<Order> getOrders() {
	//        return orders;
	//    }
	//
	//    public void setOrders(Set<Order> orders) {
	//        this.orders = orders;
	//    }

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public void setMiddleName(String middleName) {
		this.middleName = middleName;
	}

	public void setVersion(Long version) {
		this.version = version;
	}

	public void setDistrict(District district) {
		this.district = district;
	}

	public void setAddress(Address address) {
		this.address = address;
	}

	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	public void setCredit(String credit) {
		if (!credit.equals("GC") && !credit.equalsIgnoreCase("BC")) {
			throw new IllegalArgumentException();
		}
		this.credit = credit;
	}

	public void setCreditLimit(BigDecimal creditLimit) {
		this.creditLimit = creditLimit;
	}

	public void setCustomerId(Long customerId) {
		this.customerId = customerId;
	}

	public void setData(String data) {
		this.data = data;
	}

	public void setDeliveryCount(Long deliveryCount) {
		this.deliveryCount = deliveryCount;
	}

	public void setDiscount(BigDecimal discount) {
		this.discount = discount;
	}

	public void setPaymentCount(Long paymentCount) {
		this.paymentCount = paymentCount;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public void setSince(Timestamp since) {
		this.since = since;
	}

	public void setYtdPayment(BigDecimal ytdPayment) {
		this.ytdPayment = ytdPayment;
	}

	@Override
	public String toString() {
		Address address = getAddress();
		if (address != null) {
			return "Customer(id=" + getCustomerId() + ", firstName=" + getFirstName() + ", lastName=" + getLastName() + ", city=" + getAddress().getCity() + ")";
		} else {
			return "Customer(id=" + getCustomerId() + ", firstName=" + getFirstName() + ", lastName=" + getLastName() + ")";
		}
	}
}
