/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 16-Jan-2006
 * Author: Dibyendu Majumdar
 */
package entity.tpcc;

import java.io.Serializable;
import java.math.BigDecimal;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Version;

@Entity
@Table(name = "DISTRICT", schema = "TPCC")
public class District implements Serializable {

	Warehouse warehouse;

	Long id;

	Long version;

	String name;

	String street1;

	String street2;

	String city;

	String state;

	String zip;

	BigDecimal tax;

	BigDecimal ytd;

	BigDecimal nextOId;

	//    Set<Customer> customers;

	/**
	 * @see schema.entity.iface.IDistrict#getCity()
	 */
	@Column(name = "D_CITY", length = 20)
	public String getCity() {
		return city;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getId()
	 */
	@Id
	@Column(name = "D_ID", nullable = false)
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	public Long getId() {
		return id;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getName()
	 */
	@Column(name = "D_NAME", nullable = false, length = 10)
	public String getName() {
		return name;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getNextOId()
	 */
	@Column(name = "D_NEXT_O_ID", precision = 8, scale = 0)
	public BigDecimal getNextOId() {
		return nextOId;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getState()
	 */
	@Column(name = "D_STATE", length = 2)
	public String getState() {
		return state;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getStreet1()
	 */
	@Column(name = "D_STREET_1", length = 20)
	public String getStreet1() {
		return street1;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getStreet2()
	 */
	@Column(name = "D_STREET_2", length = 20)
	public String getStreet2() {
		return street2;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getTax()
	 */
	@Column(name = "D_TAX", precision = 4, scale = 0)
	public BigDecimal getTax() {
		return tax;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getVersion()
	 */
	@Version
	@Column(name = "D_VERSION")
	public Long getVersion() {
		return version;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getWarehouse()
	 */
	@ManyToOne(targetEntity = entity.tpcc.Warehouse.class, cascade={CascadeType.MERGE, CascadeType.REFRESH})
	@JoinColumn(name = "D_W_ID", referencedColumnName = "W_ID")
	public Warehouse getWarehouse() {
		return warehouse;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getYtd()
	 */
	@Column(name = "D_YTD", precision = 12, scale = 0)
	public BigDecimal getYtd() {
		return ytd;
	}

	/**
	 * @see schema.entity.iface.IDistrict#getZip()
	 */
	@Column(name = "D_ZIP", length = 9)
	public String getZip() {
		return zip;
	}

	//    @OneToMany(mappedBy="district")
	//    public Set<Customer> getCustomers() {
	//        return customers;
	//    }
	//
	//    public void setCustomers(Set<Customer> customers) {
	//        this.customers = customers;
	//    }

	/**
	 * @see schema.entity.iface.IDistrict#setCity(java.lang.String)
	 */
	public void setCity(String city) {
		this.city = city;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setId(int)
	 */
	public void setId(Long id) {
		this.id = id;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setName(java.lang.String)
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setNextOId(java.math.BigDecimal)
	 */
	public void setNextOId(BigDecimal nextOId) {
		this.nextOId = nextOId;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setState(java.lang.String)
	 */
	public void setState(String state) {
		this.state = state;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setStreet1(java.lang.String)
	 */
	public void setStreet1(String street1) {
		this.street1 = street1;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setStreet2(java.lang.String)
	 */
	public void setStreet2(String street2) {
		this.street2 = street2;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setTax(java.math.BigDecimal)
	 */
	public void setTax(BigDecimal tax) {
		this.tax = tax;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setVersion(int)
	 */
	public void setVersion(Long version) {
		this.version = version;
	}

	//    /**
	//     * @see schema.entity.iface.IDistrict#setWarehouse(schema2.entity.tpcc.Warehouse)
	//     */
	//    public void setWarehouse(Warehouse warehouse) {
	//        this.warehouse = warehouse;
	//    }

	public void setWarehouse(Warehouse warehouse) {
		this.warehouse = warehouse;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setYtd(java.math.BigDecimal)
	 */
	public void setYtd(BigDecimal ytd) {
		this.ytd = ytd;
	}

	/**
	 * @see schema.entity.iface.IDistrict#setZip(java.lang.String)
	 */
	public void setZip(String zip) {
		this.zip = zip;
	}

	@Override
	public String toString() {
		return "District(Warehouse=" + getWarehouse() + ", Id=" + getId() + ", version=" + getVersion() + ", name=" + name + ", city=" + getCity() + ")";
	}
}
