/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 24-Jan-2006
 * Author: Dibyendu Majumdar
 */
package entity.tpcc;

import java.io.Serializable;
import java.sql.Timestamp;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Version;

@Entity
@Table(name = "ORDER_HDR", schema = "TPCC")
public class Order implements Serializable {

    Long orderId;

    Long version;

    Timestamp entryDateTime;

    Long carrierId;

    Long orderLinesCount;

    Long allLocal;

    Customer customer;

    District district;
    
    Warehouse warehouse;
    
    Set<OrderLine> orderLines;
    
    @Column(name="O_ALL_LOCAL")
    public Long getAllLocal() {
        return allLocal;
    }

    @Column(name="O_CARRIER_ID")
    public Long getCarrierId() {
        return carrierId;
    }

    @Column(name="O_ENTRY_D")
//    @Temporal(TemporalType.TIMESTAMP)
    public Timestamp getEntryDateTime() {
        return entryDateTime;
    }

    @Id
    @Column(name="O_ID", nullable=false)
    public Long getOrderId() {
        return orderId;
    }

    @Column(name="O_OL_CNT")
    public Long getOrderLinesCount() {
        return orderLinesCount;
    }

    @Version
    @Column(name="O_VERSION")
    public Long getVersion() {
        return version;
    }

    @ManyToOne
    @JoinColumn(name="O_C_ID", nullable=false, referencedColumnName="C_ID")
    public Customer getCustomer() {
        return customer;
    }

    @ManyToOne
    @JoinColumn(name="O_W_ID", nullable=false, referencedColumnName="W_ID")
    public Warehouse getWarehouse() {
        return warehouse;
    }

    @ManyToOne
    @JoinColumn(name="O_D_ID", nullable=false, referencedColumnName="D_ID")
    public District getDistrict() {
        return district;
    }
    
    @OneToMany(mappedBy="order")
    public Set<OrderLine> getOrderLines() {
        return orderLines;
    }

    public void setOrderLines(Set<OrderLine> orderLines) {
        this.orderLines = orderLines;
    }

    public void setCustomer(Customer customer) {
        this.customer = customer;
    }

    public void setAllLocal(Long allLocal) {
        this.allLocal = allLocal;
    }

    public void setCarrierId(Long carrierId) {
        this.carrierId = carrierId;
    }

    public void setEntryDateTime(Timestamp entryDateTime) {
        this.entryDateTime = entryDateTime;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public void setOrderLinesCount(Long orderLinesCount) {
        this.orderLinesCount = orderLinesCount;
    }

    public void setVersion(Long version) {
        this.version = version;
    }

    public void setDistrict(District district) {
        this.district = district;
    }

    public void setWarehouse(Warehouse warehouse) {
        this.warehouse = warehouse;
    }
}
