/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 24-Jan-2006
 * Author: Dibyendu Majumdar
 */
package entity.tpcc;

import java.io.Serializable;
import java.math.BigDecimal;
import java.sql.Timestamp;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

@Entity
@Table(name="ORDER_LINE", schema="TPCC")
public class OrderLine implements Serializable {

    Long id;
    Long orderLineNumber;
    Timestamp deliveryDateTime;
    Long quantity;
    BigDecimal amount;
    String distInfo;
    
    Order order;
    Stock stock;
    
    @Column(name="OL_AMOUNT", precision=6, scale=2)
    public BigDecimal getAmount() {
        return amount;
    }
    @Column(name="OL_DELIVERY_D")
    public Timestamp getDeliveryDateTime() {
        return deliveryDateTime;
    }
    @Column(name="OL_DIST_INFO")
    public String getDistInfo() {
        return distInfo;
    }
    @Id
    @Column(name="OL_ID", nullable=false)
    public Long getId() {
        return id;
    }
    @ManyToOne
    @JoinColumn(name="OL_O_ID", referencedColumnName="O_ID")
    public Order getOrder() {
        return order;
    }
    @Column(name="OL_NUMBER", nullable=false)
    public Long getOrderLineNumber() {
        return orderLineNumber;
    }
    @Column(name="OL_QUANTITY")
    public Long getQuantity() {
        return quantity;
    }
    @ManyToOne
    @JoinColumn(name="OL_SUPPLY_S_ID", referencedColumnName="S_ID")
    public Stock getStock() {
        return stock;
    }
    
    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public void setDeliveryDateTime(Timestamp deliveryDateTime) {
        this.deliveryDateTime = deliveryDateTime;
    }
    public void setDistInfo(String distInfo) {
        this.distInfo = distInfo;
    }
    public void setOrder(Order order) {
        this.order = order;
    }
    public void setOrderLineNumber(Long orderLineNumber) {
        this.orderLineNumber = orderLineNumber;
    }
    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }
    public void setStock(Stock stock) {
        this.stock = stock;
    }
    public void setId(Long id) {
        this.id = id;
    }
}
