/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 *//*
 * Created on: 01-Feb-2006
 * Author: Dibyendu Majumdar
 */
package services.impl;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.Query;

import services.CustomerService;
import entity.tpcc.Customer;
import entity.tpcc.District;
import entity.tpcc.Warehouse;

@Stateless
public class CustomerServiceImpl implements CustomerService {

    EntityManager entityManager;

    public CustomerServiceImpl() {
    }

    public CustomerServiceImpl(EntityManager em) {
        this.entityManager = em;
    }
    
    public void createCustomer(District d, Customer c) {
        c.setDistrict(d);
        entityManager.persist(c);
    }

    public void createCustomer(String district, Customer c) {
        District d = (District) entityManager.createQuery("SELECT d FROM District d WHERE d.name = :dname")
            .setParameter("dname", district).getSingleResult();
        c.setDistrict(d);
        entityManager.persist(c);
    }

    public void removeCustomer(Customer c) {
        if (entityManager.contains(c)) {
            entityManager.remove(c);
        }
        else {
            removeCustomer(c.getCustomerId());
        }
    }

    public void removeCustomer(Long id) {
        entityManager.createQuery("DELETE FROM Customer c WHERE c.customerId = :cid").setParameter(1, id).executeUpdate();
    }
    
    @PersistenceContext(type=PersistenceContextType.TRANSACTION, unitName="em1")
    public void setEntityManager(EntityManager entityManager) {
        this.entityManager = entityManager;
    }

    public List find(Customer c) {
        QueryBuilder qb = new QueryBuilder(c, "c");
        System.err.println("Customer Query = " + qb);
        return qb.runQuery(entityManager);
    }

    public List findByDistrict(District d) {
        QueryBuilder qb = new QueryBuilder(d, "d");
        Query q = entityManager.createQuery("SELECT c FROM Customer c JOIN c.district d" + qb.getQueryString());
        Object[] parms = qb.getParameters();
        for (int i = 0; i < parms.length; i++) {
            q.setParameter(i+1, parms[i]);
        }
        return q.getResultList();
    }

    public List findByWarehouse(Warehouse w) {
        QueryBuilder qb = new QueryBuilder(w, "w");
        Query q = entityManager.createQuery("SELECT c FROM Customer c JOIN c.district d JOIN d.warehouse w" + qb.getQueryString());
        Object[] parms = qb.getParameters();
        for (int i = 0; i < parms.length; i++) {
            q.setParameter(i+1, parms[i]);
        }
        return q.getResultList();
    }
}
