/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 08-Feb-2006
 * Author: Dibyendu Majumdar
 */
package services.impl;

import java.math.BigDecimal;
import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.Query;

import entity.tpcc.District;
import entity.tpcc.Warehouse;
import services.DistrictService;

@Stateless
public class DistrictServiceImpl implements DistrictService {

    EntityManager entityManager;
    
    public DistrictServiceImpl() {
    }
    
    public DistrictServiceImpl(EntityManager entityManager) {
        this.entityManager = entityManager;
    }

    public void createDistrict(Warehouse warehouse, String name,
            String street1, String street2, String city, String state,
            String zip, BigDecimal ytd, BigDecimal tax, BigDecimal nextOrderId) {
        District d = new District();
        d.setName(name);
        d.setStreet1(street1);
        d.setStreet2(street2);
        d.setCity(city);
        d.setState(state);
        d.setZip(zip);
        d.setYtd(ytd);
        d.setTax(tax);
        d.setNextOId(nextOrderId);
        createDistrict(warehouse, d);
    }

    public void createDistrict(Warehouse warehouse, District district) {
        district.setWarehouse(warehouse);
        System.out.println("Inserting " + district);
        entityManager.persist(district);
    }

    public void updateDistrict(District district) {
        System.out.println("Updating " + district);
        if (entityManager.find(District.class, district.getId()) == null) {
            throw new RuntimeException("Unable to update " + district + " because a prior version does not exist");
        }
        entityManager.merge(district);
    }

    public void remove(District district) {
        if (entityManager.contains(district)) {
            entityManager.remove(district);
        }
        else {
            remove(district.getId());
        }
    }

    public void remove(Long id) {
        entityManager.createQuery("DELETE FROM District d WHERE d.id = :did").setParameter("did", id).executeUpdate();
    }
    
    public List find(District district) {
        return new QueryBuilder(district, "d").runQuery(entityManager);
    }

    public List findAll(Warehouse warehouse) {
        QueryBuilder qb = new QueryBuilder(warehouse, "w");
        System.out.println("QUERY=SELECT d FROM District d JOIN d.warehouse w" + qb.getQueryString());
        Query q = entityManager.createQuery("SELECT d FROM District d JOIN d.warehouse w" + qb.getQueryString());
        Object[] parms = qb.getParameters();
        for (int i = 0; i < parms.length; i++) {
            q.setParameter(i+1, parms[i]);
        }
        return q.getResultList();
    }

    @PersistenceContext(type=PersistenceContextType.TRANSACTION, unitName="em1")
    public void setEntityManager(EntityManager entityManager) {
        this.entityManager = entityManager;
    }
}
