/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 09-Feb-2006
 * Author: Dibyendu Majumdar
 */
package services.impl;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.persistence.Embeddable;
import javax.persistence.Entity;
import javax.persistence.EntityManager;
import javax.persistence.Query;

public final class QueryBuilder {

    final ArrayList<Object> parms = new ArrayList<Object>();

    final StringBuilder sb = new StringBuilder();

    int state = 0;

    final Object object;

    final String alias;

    public QueryBuilder(Object object, String alias) {
        this.object = object;
        this.alias = alias;
        buildQueryInternal(object, alias, 0);
    }

    public void buildQueryInternal(Object object, String alias, int level) {
        Class cls = object.getClass();
        if (level == 0 && !cls.isAnnotationPresent(Entity.class)) {
            throw new RuntimeException();
        } else if (level > 0
                && (!cls.isAnnotationPresent(Embeddable.class) && 
                    !cls.isAnnotationPresent(Entity.class))) {
            throw new RuntimeException("Class=" + cls.getName());
        }
        for (Method m : cls.getDeclaredMethods()) {
            if (m.getName().startsWith("get")) {
                Object result = null;
                try {
                    result = m.invoke(object, (Object[]) null);
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
                if (result != null) {
                    if (result instanceof Collection) {
                        // we don't do relationships
                        continue;
                    }
                    Class resultClass = result.getClass();
                    String fieldName = m.getName().substring(3, 4)
                            .toLowerCase()
                            + m.getName().substring(4);
                    if (resultClass.isAnnotationPresent(Embeddable.class) ||
                        resultClass.isAnnotationPresent(Entity.class)) {
                        buildQueryInternal(result, alias + "." + fieldName,
                                level + 1);
                        continue;
                    }
                    if (state == 0) {
                        sb.append(" WHERE");
                        state = 1;
                    } else {
                        sb.append(" AND");
                    }
                    sb.append(" ");
                    sb.append(alias);
                    sb.append(".");
                    sb.append(fieldName);
                    sb.append(" = ");
                    sb.append("?" + (parms.size() + 1));
                    parms.add(result);
                }
            }
        }
    }

    public int getParameterCount() {
        return parms.size();
    }

    public Object[] getParameters() {
        return parms.toArray();
    }

    public String getQueryString() {
        return sb.toString();
    }

    public List runQuery(EntityManager em) {
    	String qstr = "SELECT " + alias + " FROM "
        + object.getClass().getSimpleName() + " " + alias
        + getQueryString();
    	System.out.println("Executing " + qstr);
        Query q = em.createQuery(qstr);
        int p = 1;
        for (Object o : parms) {
            q.setParameter(p++, o);
        }
        return q.getResultList();
    }

    @Override
    public String toString() {
        return "{query=" + getQueryString() + ", paramCount="
                + getParameterCount() + "}";
    }
}
