/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * Created on: 01-Feb-2006
 * Author: Dibyendu Majumdar
 */
package services.impl;

import java.math.BigDecimal;
import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;

import services.WarehouseService;
import entity.tpcc.Warehouse;

@Stateless public class WarehouseServiceImpl implements WarehouseService {
    
    private EntityManager entityManager;
    
    public WarehouseServiceImpl() {
    }
    
    public WarehouseServiceImpl(EntityManager em) {
        this.setEntityManager(em);
    }
    
    public Warehouse createWarehouse(String name, String street1, String street2,
            String city, String state, String zip, BigDecimal tax) {
        
        Warehouse wh = new Warehouse();
        wh.setName(name);
        wh.setStreet1(street1);
        wh.setStreet2(street2);
        wh.setCity(city);
        wh.setState(state);
        wh.setZip(zip);
        wh.setTax(tax);
        wh.setYtd(new BigDecimal("0.0"));
        
        entityManager.persist(wh);
        return wh;
    }
    
    public void createWarehouse(Warehouse wh) {
        System.out.println("Inserting " + wh);
        entityManager.persist(wh);
	}

	public void updateWarehouse(Warehouse wh) {
        System.out.println("Updating " + wh);
        if (entityManager.find(Warehouse.class, wh.getId()) == null) {
            throw new RuntimeException("Unable to update " + wh + " because there is no prior version");
        }
        entityManager.merge(wh);
	}

	public void remove(Warehouse w) {
        if (entityManager.contains(w)) {
            entityManager.remove(w);
        }
        else {
            remove(w.getId());
        }
    }
    
    public void remove(Long id) {
        entityManager.createQuery("DELETE FROM Warehouse w WHERE w.id = :wid")
        .setParameter("wid", id).executeUpdate();
    }

    public List find(Warehouse w) {
        QueryBuilder qb = new QueryBuilder(w, "w");
        return qb.runQuery(entityManager);
    }
    
    @PersistenceContext(type=PersistenceContextType.TRANSACTION, unitName="em1")
    public void setEntityManager(EntityManager entityManager) {
        this.entityManager = entityManager;
    }
}
