/***
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *    Project: ejb3demo
 *    Author : Dibyendu Majumdar
 *    Email  : dibyendu@mazumdar.demon.co.uk
 */
/*
 * WarehouseEntryBean.java
 *
 * Created on 16 February 2006, 12:14
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package tpcc.jsf.model;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import javax.ejb.EJB;
import javax.faces.context.FacesContext;

import services.DistrictService;
import entity.tpcc.District;
import entity.tpcc.Warehouse;

public class DistrictFormBean {

	DistrictService districtService;

	String name;

	String street1;

	String street2;

	String city;

	String state;

	String zipCode;

	BigDecimal tax;

	BigDecimal ytd;

	String message;
    
    BigDecimal nextOrderId;

	District current = null;
	
    Warehouse myWarehouse = null;
    
	private ArrayList<District> currentSet = new ArrayList<District>();
    
	/** Creates a new instance of MasterEntryModelBean */
	public DistrictFormBean() {
	}

	private District gather() {
		District district = getCurrent();
		if (district == null) {
			district = new District();
		}
		if (name != null && name.length() > 0) {
			district.setName(name);
		}
		if (street1 != null && street1.length() > 0) {
			district.setStreet1(street1);
		}
		if (street2 != null && street2.length() > 0) {
			district.setStreet2(street2);
		}
		if (city != null && city.length() > 0) {
			district.setCity(city);
		}
		if (state != null && state.length() > 0) {
			district.setState(state);
		}
		if (zipCode != null && zipCode.length() > 0) {
			district.setZip(zipCode);
		}
		if (tax != null) {
			district.setTax(tax);
		}
		if (ytd != null) {
			district.setYtd(ytd);
		}
        if (nextOrderId != null) {
            district.setNextOId(nextOrderId);
        }
        district.setWarehouse(getMyWarehouse());
		return district;
	}

	private void scatter(District district) {
		name = district.getName();
		street1 = district.getStreet1();
		street2 = district.getStreet2();
		city = district.getCity();
		state = district.getState();
		zipCode = district.getZip();
		if (district.getTax() != null) {
			tax = district.getTax();
        }
		if (district.getYtd() != null) {
			ytd = district.getYtd();
        }
        if (district.getNextOId() != null) {
            nextOrderId = district.getNextOId();
        }
	}

	public Object find() {
        if (getMyWarehouse() == null) {
            setMessage("Warehouse not defined");
            return "district";
        }
		setMessage(null);
		setCurrent(null);
		District district = gather();
		List list = districtService.find(district);
		if (list.size() > 0) {
			currentSet.clear();
			currentSet.addAll(list);
			return "districtl";
		} else {
			setMessage("Did not find any data that matched your query");
			return "district";
		}
	}

	public Object edit() {
		current = (District) FacesContext.getCurrentInstance().getExternalContext().getRequestMap().get("item");
		scatter(current);
		return "district";
	}

	public Object add() {
        if (getMyWarehouse() == null) {
            setMessage("Warehouse not defined");
            return "district";
        }
		setCurrent(null);
		setMessage(null);
		District district = gather();
		try {
            System.out.println("District Name=" + name);
			districtService.createDistrict(getMyWarehouse(), district);
		}
		catch (Exception ex) {
			setMessage("Failed to create district " + district + ": " + ex.getMessage());
			FacesContext.getCurrentInstance().getExternalContext().log("Error occurred while attempting to save data", ex);
		}
		return "district";
	}
	
	public Object save() {
		if (getCurrent() == null) {
			setMessage("No current record");
			return "district";
		}
        if (getMyWarehouse() == null) {
            setMessage("Warehouse not defined");
            return "district";
        }
		setMessage(null);
		District district = gather();
		try {
			districtService.updateDistrict(district);
			setCurrent(null);
		}
		catch (Exception ex) {
			setMessage("Failed to save data");
			FacesContext.getCurrentInstance().getExternalContext().log("Error occurred while attempting to save data", ex);
		}
		return "district";
	}
	
	public Object listDistricts() {
        if (getMyWarehouse() == null) {
            setMessage("Warehouse not defined");
            return "warehouse";
        }
		setMessage(null);
		try {
			List list = districtService.findAll(getMyWarehouse());
			if (list.size() > 0) {
				currentSet.clear();
				currentSet.addAll(list);
			}
			return "districtl";
		}
		catch (Exception ex) {
			setMessage("Failed to obtain list of districts");
			FacesContext.getCurrentInstance().getExternalContext().log("Error occurred while attempting to obtain list of districts", ex);
		}
		return "warehouse";
	}
	
	public final String getCity() {
		return city;
	}

	public final void setCity(String city) {
		this.city = city;
	}

	public final String getName() {
		return name;
	}

	public final void setName(String name) {
		this.name = name;
	}

	public final String getState() {
		return state;
	}

	public final void setState(String state) {
		this.state = state;
	}

	public final String getStreet1() {
		return street1;
	}

	public final void setStreet1(String street1) {
		this.street1 = street1;
	}

	public final String getStreet2() {
		return street2;
	}

	public final void setStreet2(String street2) {
		this.street2 = street2;
	}

	public final BigDecimal getTax() {
		return tax;
	}

	public final void setTax(BigDecimal tax) {
		this.tax = tax;
	}

	public final BigDecimal getYtd() {
		return ytd;
	}

	public final void setYtd(BigDecimal ytd) {
		this.ytd = ytd;
	}

	public final String getZipCode() {
		return zipCode;
	}

	public final void setZipCode(String zipCode) {
		this.zipCode = zipCode;
	}

	public final ArrayList<District> getCurrentSet() {
		return currentSet;
	}

	public final void setCurrentSet(ArrayList<District> currentSet) {
		this.currentSet = currentSet;
	}

	public final String getMessage() {
		return message;
	}

	public final void setMessage(String message) {
		this.message = message;
	}

	public final District getCurrent() {
		return current;
	}

	public final void setCurrent(District current) {
		this.current = current;
	}

	public final DistrictService getDistrictService() {
		return districtService;
	}

	@EJB
	public final void setDistrictService(DistrictService districtService) {
		this.districtService = districtService;
	}

    public Warehouse getMyWarehouse() {
        return myWarehouse;
    }

    public BigDecimal getNextOrderId() {
        return nextOrderId;
    }

    public void setMyWarehouse(Warehouse myWarehouse) {
        this.myWarehouse = myWarehouse;
    }

    public void setNextOrderId(BigDecimal nextOrderId) {
        this.nextOrderId = nextOrderId;
    }
}
